@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-__version__ = '1.2.2'
+__version__ = '1.2.4'
 
 from    pathlib                 import Path
 
@@ -536,4 +536,17 @@ class Pftag:
 
     def __call__(self, tag:str, *args: Any, **kwds: Any) -> dict:
         self.options.tag = tag
-        return self.run(tag)
\ No newline at end of file
+        return self.run(tag)
+
+def timestamp_dt(str_datetime:str) -> datetime:
+    """
+    Accept a string generated by the %timestamp tag and return a
+    datetime object
+
+    Args:
+        str_datetime (str): a string generated by %timestamp
+
+    Returns:
+        datetime: a datetime object of the input
+    """
+    return datetime.strptime(str_datetime, '%Y-%m-%dT%H:%M:%S.%f%z')
